@@ -1,10 +1,12 @@
 from pathlib import Path
 
 import msgspec
+from fsspec_utils import AbstractFileSystem, BaseStorageOptions, filesystem
 from munch import Munch
 
-from ..fs import AbstractFileSystem, BaseStorageOptions, get_filesystem
+from ..settings import CONFIG_DIR, PIPELINES_DIR
 from .base import BaseConfig
+from .exceptions import ConfigLoadError, ConfigSaveError, ConfigPathError
 from .pipeline import PipelineConfig, init_pipeline_config
 from .project import ProjectConfig, init_project_config
 
@@ -20,8 +22,9 @@ class Config(BaseConfig):
         pipeline (PipelineConfig): Configuration for the pipeline.
         project (ProjectConfig): Configuration for the project.
         fs (AbstractFileSystem | None): Filesystem abstraction for I/O operations.
-        base_dir (str | Path | None): Base directory for the configuration.
-        storage_options (dict | Munch): Options for filesystem operations.
+        base_dir (str | None): Base directory for the configuration.
+        base_dir_path (pathlib.Path | None): Base directory as a Path object (property).
+        storage_options (Munch): Options for filesystem operations.
 
     Example:
         ```python
@@ -40,8 +43,61 @@ class Config(BaseConfig):
     pipeline: PipelineConfig = msgspec.field(default_factory=PipelineConfig)
     project: ProjectConfig = msgspec.field(default_factory=ProjectConfig)
     fs: AbstractFileSystem | None = None
-    base_dir: str | Path | None = None
-    storage_options: dict | Munch = msgspec.field(default_factory=Munch)
+    base_dir: str | None = None
+    storage_options: Munch = msgspec.field(default_factory=Munch)
+
+    def __post_init__(self):
+        """Handle conversion of storage_options from dict to Munch if needed."""
+        if isinstance(self.storage_options, dict):
+            self.storage_options = Munch(self.storage_options)
+        
+        # Validate storage_options
+        self._validate_storage_options()
+        
+        # Validate base_dir if provided
+        if self.base_dir is not None:
+            self._validate_base_dir()
+
+    def _validate_storage_options(self) -> None:
+        """Validate storage_options parameter.
+        
+        Raises:
+            ValueError: If storage_options contains invalid values.
+        """
+        if self.storage_options is None:
+            self.storage_options = Munch()
+        
+        if not isinstance(self.storage_options, (dict, Munch)):
+            raise ValueError(f"storage_options must be a dict or Munch, got {type(self.storage_options)}")
+
+    def _validate_base_dir(self) -> None:
+        """Validate base_dir parameter.
+        
+        Raises:
+            ValueError: If base_dir contains invalid characters or is empty.
+        """
+        # Convert Path to string if needed
+        base_dir_str = str(self.base_dir) if hasattr(self.base_dir, '__str__') else self.base_dir
+        
+        if not isinstance(base_dir_str, str):
+            raise ValueError(f"base_dir must be a string or Path, got {type(self.base_dir)}")
+        
+        # Check for directory traversal attempts (but allow absolute paths)
+        if '..' in base_dir_str:
+            raise ValueError(f"Invalid base_dir: {base_dir_str}. Contains path traversal characters.")
+        
+        # Check for empty string
+        if not base_dir_str.strip():
+            raise ValueError("base_dir cannot be empty or whitespace only.")
+
+    @property
+    def base_dir_path(self) -> Path | None:
+        """Get base_dir as a pathlib.Path object.
+        
+        Returns:
+            pathlib.Path | None: The base directory as a Path object, or None if base_dir is None.
+        """
+        return Path(self.base_dir) if self.base_dir is not None else None
 
     @classmethod
     def load(
@@ -49,7 +105,6 @@ class Config(BaseConfig):
         base_dir: str = ".",
         name: str | None = None,
         pipeline_name: str | None = None,
-        job_queue_type: str | None = None,
         fs: AbstractFileSystem | None = None,
         storage_options: dict | BaseStorageOptions | None = {},
     ):
@@ -59,7 +114,6 @@ class Config(BaseConfig):
             base_dir (str, optional): Base directory for configurations. Defaults to ".".
             name (str | None, optional): Project name. Defaults to None.
             pipeline_name (str | None, optional): Pipeline name. Defaults to None.
-            job_queue_type (str | None, optional): Type of job queue to use. Defaults to None.
             fs (AbstractFileSystem | None, optional): Filesystem to use. Defaults to None.
             storage_options (dict | Munch, optional): Options for filesystem. Defaults to empty Munch.
 
@@ -72,27 +126,33 @@ class Config(BaseConfig):
                 base_dir="my_project",
                 name="test_project",
                 pipeline_name="etl",
-                job_queue_type="rq"
             )
             ```
         """
         if fs is None:
-            fs = get_filesystem(
-                base_dir, cached=True, dirfs=True, storage_options=storage_options
+            # Use cached filesystem for better performance
+            storage_options_hash = cls._hash_storage_options(storage_options)
+            fs = cls._get_cached_filesystem(base_dir, storage_options_hash)
+        
+        try:
+            project = ProjectConfig.load(
+                base_dir=base_dir,
+                name=name,
+                fs=fs,
+                storage_options=storage_options,
             )
-        project = ProjectConfig.load(
-            base_dir=base_dir,
-            name=name,
-            job_queue_type=job_queue_type,
-            fs=fs,
-            storage_options=storage_options,
-        )
-        pipeline = PipelineConfig.load(
-            base_dir=base_dir,
-            name=pipeline_name,
-            fs=fs,
-            storage_options=storage_options,
-        )
+        except ConfigLoadError as e:
+            raise ConfigLoadError(f"Failed to load project configuration: {e}", path=base_dir, original_error=e)
+            
+        try:
+            pipeline = PipelineConfig.load(
+                base_dir=base_dir,
+                name=pipeline_name,
+                fs=fs,
+                storage_options=storage_options,
+            )
+        except ConfigLoadError as e:
+            raise ConfigLoadError(f"Failed to load pipeline configuration: {e}", path=base_dir, original_error=e)
 
         return cls(
             base_dir=base_dir,
@@ -123,23 +183,32 @@ class Config(BaseConfig):
             ```
         """
         if fs is None and self.fs is None:
-            self.fs = get_filesystem(
-                self.base_dir, cached=True, dirfs=True, **storage_options
-            )
+            # Use cached filesystem for better performance
+            storage_options_hash = self._hash_storage_options(storage_options)
+            self.fs = self._get_cached_filesystem(self.base_dir, storage_options_hash)
 
-        if not self.fs.exists("conf"):
-            self.fs.makedirs("conf")
+        if not self.fs.exists(CONFIG_DIR):
+            self.fs.makedirs(CONFIG_DIR)
 
         if pipeline:
-            self.fs.makedirs("conf/pipelines", exist_ok=True)
+            self.fs.makedirs(PIPELINES_DIR, exist_ok=True)
             h_params = self.pipeline.pop("h_params") if self.pipeline.h_params else None
-            self.pipeline.to_yaml(
-                path=f"conf/pipelines/{self.pipeline.name}.yml", fs=self.fs
-            )
+            # Validate pipeline name to prevent directory traversal
+            if self.pipeline.name and ('..' in self.pipeline.name or '/' in self.pipeline.name or '\\' in self.pipeline.name):
+                raise ConfigPathError(f"Invalid pipeline name: {self.pipeline.name}. Contains path traversal characters.", path=self.pipeline.name)
+            try:
+                self.pipeline.to_yaml(
+                    path=f"conf/pipelines/{self.pipeline.name}.yml", fs=self.fs
+                )
+            except ConfigSaveError as e:
+                raise ConfigSaveError(f"Failed to save pipeline configuration: {e}", path=f"conf/pipelines/{self.pipeline.name}.yml", original_error=e)
             if h_params:
                 self.pipeline.h_params = h_params
         if project:
-            self.project.to_yaml("conf/project.yml", self.fs)
+            try:
+                self.project.to_yaml("conf/project.yml", self.fs)
+            except ConfigSaveError as e:
+                raise ConfigSaveError(f"Failed to save project configuration: {e}", path="conf/project.yml", original_error=e)
 
 
 def load(
@@ -210,7 +279,6 @@ def init_config(
     base_dir: str = ".",
     name: str | None = None,
     pipeline_name: str | None = None,
-    job_queue_type: str | None = None,
     fs: AbstractFileSystem | None = None,
     storage_options: dict | BaseStorageOptions | None = {},
 ):
@@ -223,7 +291,6 @@ def init_config(
         base_dir (str, optional): Base directory for configurations. Defaults to ".".
         name (str | None, optional): Project name. Defaults to None.
         pipeline_name (str | None, optional): Pipeline name. Defaults to None.
-        job_queue_type (str | None, optional): Type of job queue to use. Defaults to None.
         fs (AbstractFileSystem | None, optional): Filesystem to use. Defaults to None.
         storage_options (dict | Munch, optional): Options for filesystem. Defaults to empty Munch.
 
@@ -236,7 +303,6 @@ def init_config(
             base_dir="my_project",
             name="test_project",
             pipeline_name="data-pipeline",
-            job_queue_type="rq"
         )
         ```
     """
@@ -249,8 +315,53 @@ def init_config(
     project_cfg = init_project_config(
         base_dir=base_dir,
         name=name,
-        job_queue_type=job_queue_type,
         fs=fs,
         storage_options=storage_options,
     )
     return Config(pipeline=pipeline_cfg, project=project_cfg, fs=fs, base_dir=base_dir)
+
+
+# Helper methods for centralized load/save logic
+@classmethod
+def _load_config(
+    cls,
+    config_class: type[BaseConfig],
+    base_dir: str,
+    name: str | None,
+    fs: AbstractFileSystem,
+    storage_options: dict | BaseStorageOptions | None,
+) -> BaseConfig:
+    """Centralized configuration loading logic.
+    
+    Args:
+        config_class: The configuration class to load.
+        base_dir: Base directory for configurations.
+        name: Configuration name.
+        fs: Filesystem instance.
+        storage_options: Options for filesystem.
+        
+    Returns:
+        Loaded configuration instance.
+    """
+    return config_class.load(
+        base_dir=base_dir,
+        name=name,
+        fs=fs,
+        storage_options=storage_options,
+    )
+
+
+def _save_pipeline_config(self) -> None:
+    """Save pipeline configuration with proper handling of h_params."""
+    self.fs.makedirs(PIPELINES_DIR, exist_ok=True)
+    h_params = self.pipeline.pop("h_params") if self.pipeline.h_params else None
+    self.pipeline.to_yaml(
+        path=f"conf/pipelines/{self.pipeline.name}.yml", fs=self.fs
+    )
+    if h_params:
+        self.pipeline.h_params = h_params
+
+
+def _save_project_config(self) -> None:
+    """Save project configuration."""
+    self.project.to_yaml("conf/project.yml", self.fs)
