@@ -4,7 +4,7 @@ import os
 import typer
 from loguru import logger
 
-from ..flowerpower import init as init_
+from ..flowerpower import FlowerPowerProject
 from .pipeline import app as pipeline_app
 from .utils import parse_dict_or_list_param
 
@@ -18,21 +18,6 @@ app.add_typer(
     pipeline_app, name="pipeline", help="Manage and execute FlowerPower pipelines"
 )
 
-if importlib.util.find_spec("apscheduler") or importlib.util.find_spec("rq"):
-    from .job_queue import app as job_queue_app
-
-    app.add_typer(
-        job_queue_app,
-        name="job-queue",
-        help="Manage job queue workers and scheduled tasks",
-    )
-
-if importlib.util.find_spec("paho"):
-    from .mqtt import app as mqtt_app
-
-    app.add_typer(
-        mqtt_app, name="mqtt", help="Connect pipelines to MQTT message brokers"
-    )
 
 
 @app.command()
@@ -49,12 +34,6 @@ def init(
     storage_options: str = typer.Option(
         None, "--storage-options", "-s", help="Storage options as a JSON or dict string"
     ),
-    job_queue_type: str = typer.Option(
-        "rq",
-        "--job-queue-type",
-        "-q",
-        help="Job queue backend type to use (rq, apscheduler)",
-    ),
 ):
     """
     Initialize a new FlowerPower project.
@@ -69,7 +48,6 @@ def init(
         base_dir: Base directory where the project will be created. If not provided,
                   the current directory's parent will be used
         storage_options: Storage options for filesystem access, as a JSON or dict string
-        job_queue_type: Type of job queue backend to use (rq, apscheduler)
 
     Examples:
         # Create a project in the current directory using its name
@@ -80,9 +58,6 @@ def init(
 
         # Create a project in a specific location
         $ flowerpower init --name my-project --base-dir /path/to/projects
-
-        # Create a project with APScheduler as the job queue backend
-        $ flowerpower init --job-queue-type apscheduler
     """
     parsed_storage_options = {}
     if storage_options:
@@ -90,19 +65,24 @@ def init(
             parsed_storage_options = (
                 parse_dict_or_list_param(storage_options, "dict") or {}
             )
-        except Exception as e:
+        except (ValueError, SyntaxError, json.JSONDecodeError) as e:
             logger.error(f"Error parsing storage options: {e}")
             raise typer.Exit(code=1)
 
     try:
-        init_(
+        FlowerPowerProject.new(
             name=project_name,
             base_dir=base_dir,
             storage_options=parsed_storage_options,
-            job_queue_type=job_queue_type,
         )
+    except (FileNotFoundError, PermissionError, OSError) as e:
+        logger.error(f"File system error initializing project: {e}")
+        raise typer.Exit(code=1)
+    except ValueError as e:
+        logger.error(f"Invalid configuration for project: {e}")
+        raise typer.Exit(code=1)
     except Exception as e:
-        logger.error(f"Error initializing project: {e}")
+        logger.error(f"Unexpected error initializing project: {e}")
         raise typer.Exit(code=1)
 
 
