@@ -1,20 +1,41 @@
 # Import necessary libraries
-import datetime as dt
-
-import duration_parser
 import typer
 from loguru import logger
-from typing_extensions import Annotated
+from typing_extensions import Annotated, Callable, Any
+from typing import Dict, List, Optional, Tuple
 
+from ..flowerpower import FlowerPowerProject
 from ..pipeline.manager import HookType, PipelineManager
+from ..cfg.pipeline.run import RunConfig
 from ..utils.logging import setup_logging
-from .utils import parse_dict_or_list_param  # , parse_param_dict
+from .utils import parse_dict_or_list_param
 
 setup_logging()
 
 app = typer.Typer(help="Pipeline management commands")
 
 
+# Note: common_options decorator removed as it was causing TypeError
+# Options are now defined directly in each function's parameter list
+
+
+def parse_common_options(
+    base_dir: Optional[str] = None,
+    storage_options: Optional[str] = None,
+    log_level: Optional[str] = None,
+) -> Tuple[Optional[str], Dict, Optional[str]]:
+    """Parse common CLI options and return processed values."""
+    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    # Ensure storage_options is always a dict, not None or list
+    if parsed_storage_options is None:
+        parsed_storage_options = {}
+    elif not isinstance(parsed_storage_options, dict):
+        # This should not happen with param_type="dict", but being safe
+        logger.warning(f"Expected dict for storage_options, got {type(parsed_storage_options)}")
+        parsed_storage_options = {}
+    return base_dir, parsed_storage_options, log_level
+
+
 @app.command()
 def run(
     name: str = typer.Argument(..., help="Name of the pipeline to run"),
@@ -97,450 +118,84 @@ def run(
         # Configure automatic retries on failure
         $ pipeline run my_pipeline --max-retries 3 --retry-delay 2.0 --jitter-factor 0.2
     """
-    parsed_inputs = parse_dict_or_list_param(inputs, "dict")
-    parsed_config = parse_dict_or_list_param(config, "dict")
-    parsed_cache = parse_dict_or_list_param(cache, "dict")
-    parsed_final_vars = parse_dict_or_list_param(final_vars, "list")
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
-    parsed_with_adapter = parse_dict_or_list_param(with_adapter, "dict")
+    # Parse parameters with proper type handling
+    parsed_inputs = parse_dict_or_list_param(inputs, "dict") or {}
+    parsed_config = parse_dict_or_list_param(config, "dict") or {}
+    parsed_cache = parse_dict_or_list_param(cache, "dict") or {}
+    parsed_final_vars = parse_dict_or_list_param(final_vars, "list") or []
+    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict") or {}
+    parsed_with_adapter = parse_dict_or_list_param(with_adapter, "dict") or {}
+    
+    # Ensure proper types for RunConfig
+    if parsed_inputs is not None and not isinstance(parsed_inputs, dict):
+        parsed_inputs = {}
+    if parsed_config is not None and not isinstance(parsed_config, dict):
+        parsed_config = {}
+    if parsed_cache is not None and not isinstance(parsed_cache, (dict, bool)):
+        parsed_cache = False
+    if parsed_final_vars is not None and not isinstance(parsed_final_vars, list):
+        parsed_final_vars = []
+    if parsed_with_adapter is not None and not isinstance(parsed_with_adapter, dict):
+        parsed_with_adapter = {}
+    
+    # Ensure storage_options is a dict for FlowerPowerProject.load
+    if parsed_storage_options is not None and not isinstance(parsed_storage_options, dict):
+        parsed_storage_options = {}
+    
+    # Create WithAdapterConfig object if needed
+    from ..cfg.pipeline.run import WithAdapterConfig
+    if isinstance(parsed_with_adapter, dict):
+        with_adapter_config = WithAdapterConfig.from_dict(parsed_with_adapter)
+    else:
+        with_adapter_config = WithAdapterConfig()
 
-    with PipelineManager(
+    # Use FlowerPowerProject for better consistency with the new architecture
+    project = FlowerPowerProject.load(
         base_dir=base_dir,
         storage_options=parsed_storage_options or {},
         log_level=log_level,
-    ) as manager:
-        _ = manager.run(
-            name=name,
+    )
+
+    if project is None:
+        logger.error(f"Failed to load FlowerPower project from {base_dir or '.'}")
+        raise typer.Exit(1)
+
+    try:
+        # Construct RunConfig object from parsed CLI arguments
+        run_config = RunConfig(
             inputs=parsed_inputs,
             final_vars=parsed_final_vars,
             config=parsed_config,
             cache=parsed_cache,
-            executor_cfg=executor,
-            with_adapter_cfg=parsed_with_adapter,
+            with_adapter=with_adapter_config,  # type: ignore
             max_retries=max_retries,
             retry_delay=retry_delay,
             jitter_factor=jitter_factor,
         )
+        
+        # Handle executor configuration
+        if executor is not None:
+            run_config.executor.type = executor
+
+        _ = project.run(name=name, run_config=run_config)
         logger.info(f"Pipeline '{name}' finished running.")
-
-
-@app.command()
-def run_job(
-    name: str = typer.Argument(..., help="Name or ID of the pipeline job to run"),
-    executor: str | None = typer.Option(
-        None, help="Executor to use for running the job"
-    ),
-    base_dir: str | None = typer.Option(None, help="Base directory for the pipeline"),
-    inputs: str | None = typer.Option(
-        None, help="Input parameters as JSON, dict string, or key=value pairs"
-    ),
-    final_vars: str | None = typer.Option(None, help="Final variables as JSON or list"),
-    config: str | None = typer.Option(
-        None, help="Config for the hamilton pipeline executor"
-    ),
-    cache: str | None = typer.Option(
-        None, help="Cache configuration as JSON or dict string"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
-    with_adapter: str | None = typer.Option(
-        None, help="Adapter configuration as JSON or dict string"
-    ),
-    max_retries: int = typer.Option(
-        0, help="Maximum number of retry attempts on failure"
-    ),
-    retry_delay: float = typer.Option(
-        1.0, help="Base delay between retries in seconds"
-    ),
-    jitter_factor: float = typer.Option(
-        0.1, help="Random factor applied to delay for jitter (0-1)"
-    ),
-):
-    """
-    Run a specific pipeline job.
-
-    This command runs an existing job by its ID. The job should have been previously
-    added to the system via the add-job command or through scheduling.
-
-    Args:
-        name: Job ID to run
-        executor: Type of executor to use (maps to executor_cfg in manager)
-        base_dir: Base directory containing pipelines and configurations
-        inputs: Input parameters for the pipeline
-        final_vars: Final variables to request from the pipeline
-        config: Configuration for the Hamilton executor
-        cache: Cache configuration
-        storage_options: Options for storage backends
-        log_level: Set the logging level
-        with_adapter: Configuration for adapters like trackers or monitors
-        max_retries: Maximum number of retry attempts on failure
-        retry_delay: Base delay between retries in seconds
-        jitter_factor: Random factor applied to delay for jitter (0-1)
-
-    Examples:
-        # Run a job with a specific ID
-        $ pipeline run-job job-123456
-
-        # Run a job with custom inputs
-        $ pipeline run-job job-123456 --inputs '{"data_path": "data/myfile.csv"}'
-
-        # Specify a different executor
-        $ pipeline run-job job-123456 --executor local
-
-        # Use caching for better performance
-        $ pipeline run-job job-123456 --cache '{"type": "memory"}'
-
-        # Configure adapters for monitoring
-        $ pipeline run-job job-123456 --with-adapter '{"tracker": true, "opentelemetry": false}'
-
-        # Set up automatic retries for resilience
-        $ pipeline run-job job-123456 --max-retries 3 --retry-delay 2.0
-    """
-    parsed_inputs = parse_dict_or_list_param(inputs, "dict")
-    parsed_config = parse_dict_or_list_param(config, "dict")
-    parsed_cache = parse_dict_or_list_param(cache, "dict")
-    parsed_final_vars = parse_dict_or_list_param(final_vars, "list")
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
-    parsed_with_adapter = parse_dict_or_list_param(with_adapter, "dict")
-
-    with PipelineManager(
-        base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
-        log_level=log_level,
-    ) as manager:
-        _ = manager.run_job(
-            name=name,
-            inputs=parsed_inputs,
-            final_vars=parsed_final_vars,
-            config=parsed_config,
-            cache=parsed_cache,
-            executor_cfg=executor,
-            with_adapter_cfg=parsed_with_adapter,
-            max_retries=max_retries,
-            retry_delay=retry_delay,
-            jitter_factor=jitter_factor,
-        )
-        logger.info(f"Job '{name}' finished running.")
-
-
-@app.command()
-def add_job(
-    name: str = typer.Argument(..., help="Name of the pipeline to add as a job"),
-    executor: str | None = typer.Option(
-        None, help="Executor to use for running the job"
-    ),
-    base_dir: str | None = typer.Option(None, help="Base directory for the pipeline"),
-    inputs: str | None = typer.Option(
-        None, help="Input parameters as JSON, dict string, or key=value pairs"
-    ),
-    final_vars: str | None = typer.Option(None, help="Final variables as JSON or list"),
-    config: str | None = typer.Option(
-        None, help="Config for the hamilton pipeline executor"
-    ),
-    cache: str | None = typer.Option(
-        None, help="Cache configuration as JSON or dict string"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
-    with_adapter: str | None = typer.Option(
-        None, help="Adapter configuration as JSON or dict string"
-    ),
-    run_at: str | None = typer.Option(None, help="Run at a specific time (ISO format)"),
-    run_in: str | None = typer.Option(
-        None, help="Run in a specific interval (e.g., '5m', '1h', '12m34s')"
-    ),
-    max_retries: int = typer.Option(
-        3, help="Maximum number of retry attempts on failure"
-    ),
-    retry_delay: float = typer.Option(
-        1.0, help="Base delay between retries in seconds"
-    ),
-    jitter_factor: float = typer.Option(
-        0.1, help="Random factor applied to delay for jitter (0-1)"
-    ),
-):
-    """
-    Add a pipeline job to the queue.
-
-    This command adds a job to the queue for later execution. The job is based on
-    an existing pipeline with customized inputs and configuration.
-
-    Args:
-        name: Pipeline name to add as a job
-        executor: Type of executor to use
-        base_dir: Base directory containing pipelines and configurations
-        inputs: Input parameters for the pipeline
-        final_vars: Final variables to request from the pipeline
-        config: Configuration for the Hamilton executor
-        cache: Cache configuration
-        storage_options: Options for storage backends
-        log_level: Set the logging level
-        with_adapter: Configuration for adapters like trackers or monitors
-        run_at: Run the job at a specific time (ISO format)
-        run_in: Run the job in a specific interval (e.g., '5m', '1h')
-        max_retries: Maximum number of retry attempts on failure
-        retry_delay: Base delay between retries in seconds
-        jitter_factor: Random factor applied to delay for jitter (0-1)
-
-    Examples:
-        # Add a basic job
-        $ pipeline add-job my_pipeline
-
-        # Add a job with custom inputs
-        $ pipeline add-job my_pipeline --inputs '{"data_path": "data/myfile.csv"}'
-
-        # Specify final variables to calculate
-        $ pipeline add-job my_pipeline --final-vars '["output_table", "metrics"]'
-
-        # Configure caching
-        $ pipeline add-job my_pipeline --cache '{"type": "memory", "ttl": 3600}'
-
-        # Use a specific log level
-        $ pipeline add-job my_pipeline --log-level debug
-
-        # Configure automatic retries for resilience
-        $ pipeline add-job my_pipeline --max-retries 5 --retry-delay 2.0 --jitter-factor 0.2
-    """
-    parsed_inputs = parse_dict_or_list_param(inputs, "dict")
-    parsed_config = parse_dict_or_list_param(config, "dict")
-    parsed_cache = parse_dict_or_list_param(cache, "dict")
-    parsed_final_vars = parse_dict_or_list_param(final_vars, "list")
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
-    parsed_with_adapter = parse_dict_or_list_param(with_adapter, "dict")
-    run_at = dt.datetime.fromisoformat(run_at) if run_at else None
-    run_in = duration_parser.parse(run_in) if run_in else None
-
-    with PipelineManager(
-        base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
-        log_level=log_level,
-    ) as manager:
-        job_id = manager.add_job(
-            name=name,
-            inputs=parsed_inputs,
-            final_vars=parsed_final_vars,
-            config=parsed_config,
-            cache=parsed_cache,
-            executor_cfg=executor,
-            with_adapter_cfg=parsed_with_adapter,
-            run_at=run_at,
-            run_in=run_in,
-            max_retries=max_retries,
-            retry_delay=retry_delay,
-            jitter_factor=jitter_factor,
-        )
-        logger.info(f"Job {job_id} added for pipeline '{name}'.")
-
-
-@app.command()
-def schedule(
-    name: str = typer.Argument(..., help="Name of the pipeline to schedule"),
-    executor: str | None = typer.Option(
-        None, help="Executor to use for running the job"
-    ),
-    base_dir: str | None = typer.Option(None, help="Base directory for the pipeline"),
-    inputs: str | None = typer.Option(
-        None, help="Input parameters as JSON, dict string, or key=value pairs"
-    ),
-    final_vars: str | None = typer.Option(None, help="Final variables as JSON or list"),
-    config: str | None = typer.Option(
-        None, help="Config for the hamilton pipeline executor"
-    ),
-    cache: str | None = typer.Option(
-        None, help="Cache configuration as JSON or dict string"
-    ),
-    cron: str | None = typer.Option(None, help="Cron expression for scheduling"),
-    interval: str | None = typer.Option(
-        None, help="Interval for scheduling (e.g., '5m', '1h')"
-    ),
-    date: str | None = typer.Option(
-        None, help="Specific date and time for scheduling (ISO format)"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
-    with_adapter: str | None = typer.Option(
-        None, help="Adapter configuration as JSON or dict string"
-    ),
-    overwrite: bool = typer.Option(
-        False, help="Overwrite existing schedule if it exists"
-    ),
-    schedule_id: str | None = typer.Option(
-        None, help="Custom ID for the schedule (autogenerated if not provided)"
-    ),
-    max_retries: int = typer.Option(
-        3, help="Maximum number of retry attempts on failure"
-    ),
-    retry_delay: float = typer.Option(
-        1.0, help="Base delay between retries in seconds"
-    ),
-    jitter_factor: float = typer.Option(
-        0.1, help="Random factor applied to delay for jitter (0-1)"
-    ),
-):
-    """
-    Schedule a pipeline to run at specified times.
-
-    This command schedules a pipeline to run automatically based on various
-    scheduling triggers like cron expressions, time intervals, or specific dates.
-
-    Args:
-        name: Pipeline name to schedule
-        executor: Type of executor to use
-        base_dir: Base directory containing pipelines and configurations
-        inputs: Input parameters for the pipeline
-        final_vars: Final variables to request from the pipeline
-        config: Configuration for the Hamilton executor
-        cache: Cache configuration
-        cron: Cron expression for scheduling (e.g., "0 * * * *")
-        interval: Interval for scheduling (e.g., "5m", "1h")
-        date: Specific date and time for scheduling (ISO format)
-        storage_options: Options for storage backends
-        log_level: Set the logging level
-        with_adapter: Configuration for adapters like trackers or monitors
-        overwrite: Overwrite existing schedule with same ID
-        schedule_id: Custom identifier for the schedule
-        max_retries: Maximum number of retry attempts on failure
-        retry_delay: Base delay between retries in seconds
-        jitter_factor: Random factor applied to delay for jitter (0-1)
-
-    Examples:
-        # Schedule with cron expression (every hour)
-        $ pipeline schedule my_pipeline --trigger-type cron --crontab "0 * * * *"
-
-        # Schedule to run every 15 minutes
-        $ pipeline schedule my_pipeline --trigger-type interval --interval_params minutes=15
-
-        # Schedule to run at a specific date and time
-        $ pipeline schedule my_pipeline --trigger-type date --date_params run_date="2025-12-31 23:59:59"
-
-        # Schedule with custom inputs and cache settings
-        $ pipeline schedule my_pipeline --inputs '{"source": "database"}' --cache '{"type": "redis"}'
-
-        # Create a schedule in paused state
-        $ pipeline schedule my_pipeline --crontab "0 9 * * 1-5" --paused
-
-        # Set a custom schedule ID
-        $ pipeline schedule my_pipeline --crontab "0 12 * * *" --schedule_id "daily-noon-run"
-
-        # Configure automatic retries for resilience
-        $ pipeline schedule my_pipeline --max-retries 5 --retry-delay 2.0 --jitter-factor 0.2
-    """
-    parsed_inputs = parse_dict_or_list_param(inputs, "dict")
-    parsed_config = parse_dict_or_list_param(config, "dict")
-    parsed_cache = parse_dict_or_list_param(cache, "dict")
-    parsed_final_vars = parse_dict_or_list_param(final_vars, "list")
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
-    parsed_with_adapter = parse_dict_or_list_param(with_adapter, "dict")
-    interval = duration_parser.parse(interval) if interval else None
-    cron = cron if cron else None
-    date = dt.datetime.fromisoformat(date) if date else None
-
-    with PipelineManager(
-        base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
-        log_level=log_level,
-    ) as manager:
-        # Combine common schedule kwargs
-
-        id_ = manager.schedule(
-            name=name,
-            inputs=parsed_inputs,
-            final_vars=parsed_final_vars,
-            config=parsed_config,
-            cache=parsed_cache,
-            executor_cfg=executor,
-            with_adapter_cfg=parsed_with_adapter,
-            cron=cron,
-            interval=interval,
-            date=date,
-            overwrite=overwrite,
-            schedule_id=schedule_id,
-            max_retries=max_retries,
-            retry_delay=retry_delay,
-            jitter_factor=jitter_factor,
-        )
-
-    logger.info(f"Pipeline '{name}' scheduled with ID {id_}.")
-
-
-@app.command()
-def schedule_all(
-    executor: str | None = typer.Option(
-        None, help="Override executor specified in pipeline configs"
-    ),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing pipelines and configurations"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
-    overwrite: bool = typer.Option(
-        False, help="Overwrite existing schedules if they exist"
-    ),
-):
-    """
-    Schedule all pipelines based on their individual configurations.
-
-    This command reads the configuration files for all pipelines in the project
-    and schedules them based on their individual scheduling settings. This is useful
-    for setting up all scheduled pipelines at once after deployment or system restart.
-
-    Args:
-        executor: Override executor specified in pipeline configs
-        base_dir: Base directory containing pipelines and configurations
-        storage_options: Options for storage backends
-        log_level: Set the logging level
-        overwrite: Whether to overwrite existing schedules
-
-    Examples:
-        # Schedule all pipelines using their configurations
-        $ pipeline schedule-all
-
-        # Force overwrite of existing schedules
-        $ pipeline schedule-all --overwrite
-
-        # Override executor for all pipelines
-        $ pipeline schedule-all --executor distributed
-
-        # Set custom base directory
-        $ pipeline schedule-all --base-dir /path/to/project
-    """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
-
-    with PipelineManager(
-        base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
-        log_level=log_level,
-    ) as manager:
-        manager.schedule_all(overwrite=overwrite, executor_cfg=executor)
-    logger.info("Scheduled all pipelines based on their configurations.")
+    except (FileNotFoundError, PermissionError, OSError) as e:
+        logger.error(f"File system error during pipeline execution: {e}")
+        raise typer.Exit(1)
+    except ValueError as e:
+        logger.error(f"Invalid configuration for pipeline execution: {e}")
+        raise typer.Exit(1)
+    except Exception as e:
+        logger.error(f"Pipeline execution failed: {e}")
+        raise typer.Exit(1)
 
 
 @app.command()
 def new(
     name: str = typer.Argument(..., help="Name of the pipeline to create"),
-    base_dir: str | None = typer.Option(None, help="Base directory for the pipeline"),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     overwrite: bool = typer.Option(
         False, help="Overwrite existing pipeline if it exists"
     ),
@@ -569,10 +224,12 @@ def new(
         # Create a pipeline in a specific directory
         $ pipeline new my_new_pipeline --base-dir /path/to/project
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         manager.new(name=name, overwrite=overwrite)
@@ -582,21 +239,15 @@ def new(
 @app.command()
 def delete(
     name: str = typer.Argument(..., help="Name of the pipeline to delete"),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing the pipeline"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     cfg: bool = typer.Option(
         False, "--cfg", "-c", help="Delete only the configuration file"
     ),
     module: bool = typer.Option(
         False, "--module", "-m", help="Delete only the pipeline module"
     ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
 ):
     """
     Delete a pipeline's configuration and/or module files.
@@ -622,7 +273,9 @@ def delete(
         # Delete only the module file
         $ pipeline delete my_pipeline --module
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
 
     # If neither flag is set, default to deleting both
     delete_cfg = cfg or not (cfg or module)
@@ -630,7 +283,7 @@ def delete(
 
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         manager.delete(name=name, cfg=delete_cfg, module=delete_module)
@@ -650,15 +303,9 @@ def delete(
 @app.command()
 def show_dag(
     name: str = typer.Argument(..., help="Name of the pipeline to visualize"),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing the pipeline"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     format: str = typer.Option(
         "png", help="Output format (e.g., png, svg, pdf). If 'raw', returns object."
     ),
@@ -686,12 +333,14 @@ def show_dag(
         # Get raw graphviz object
         $ pipeline show-dag my_pipeline --format raw
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
     is_raw = format.lower() == "raw"
 
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         # Manager's show_dag likely handles rendering or returning raw object
@@ -710,6 +359,10 @@ def show_dag(
             logger.error(
                 "Graphviz is not installed. Cannot show/save DAG. Install with: pip install graphviz"
             )
+        except (FileNotFoundError, PermissionError, OSError) as e:
+            logger.error(f"File system error generating DAG for pipeline '{name}': {e}")
+        except ValueError as e:
+            logger.error(f"Invalid configuration for DAG generation: {e}")
         except Exception as e:
             logger.error(f"Failed to generate DAG for pipeline '{name}': {e}")
 
@@ -717,15 +370,9 @@ def show_dag(
 @app.command()
 def save_dag(
     name: str = typer.Argument(..., help="Name of the pipeline to visualize"),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing the pipeline"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     format: str = typer.Option("png", help="Output format (e.g., png, svg, pdf)"),
     output_path: str | None = typer.Option(
         None, help="Custom path to save the file (default: <name>.<format>)"
@@ -755,10 +402,12 @@ def save_dag(
         # Save to a custom location
         $ pipeline save-dag my_pipeline --output-path ./visualizations/my_graph.png
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         try:
@@ -770,21 +419,19 @@ def save_dag(
             logger.error(
                 "Graphviz is not installed. Cannot save DAG. Install with: pip install graphviz"
             )
+        except (FileNotFoundError, PermissionError, OSError) as e:
+            logger.error(f"File system error saving DAG for pipeline '{name}': {e}")
+        except ValueError as e:
+            logger.error(f"Invalid configuration for DAG saving: {e}")
         except Exception as e:
             logger.error(f"Failed to save DAG for pipeline '{name}': {e}")
 
 
 @app.command()
 def show_pipelines(
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing pipelines"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     format: str = typer.Option("table", help="Output format (table, json, yaml)"),
 ):
     """
@@ -809,10 +456,12 @@ def show_pipelines(
         # List pipelines from a specific directory
         $ pipeline show-pipelines --base-dir /path/to/project
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         manager.show_pipelines(format=format)
@@ -826,15 +475,9 @@ def show_summary(
     cfg: bool = typer.Option(True, help="Include configuration details"),
     code: bool = typer.Option(True, help="Include code/module details"),
     project: bool = typer.Option(True, help="Include project context"),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing pipelines"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
     to_html: bool = typer.Option(False, help="Output summary as HTML"),
     to_svg: bool = typer.Option(False, help="Output summary as SVG (if applicable)"),
     output_file: str | None = typer.Option(
@@ -873,10 +516,12 @@ def show_summary(
         # Generate HTML report
         $ pipeline show-summary --to-html --output-file pipeline_report.html
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         # Assumes manager.show_summary handles printing/returning formatted output
@@ -914,15 +559,9 @@ def add_hook(
     to: str | None = typer.Option(
         None, help="Target node name or tag (required for node hooks)"
     ),
-    base_dir: str | None = typer.Option(
-        None, help="Base directory containing the pipeline"
-    ),
-    storage_options: str | None = typer.Option(
-        None, help="Storage options as JSON, dict string, or key=value pairs"
-    ),
-    log_level: str | None = typer.Option(
-        None, help="Logging level (debug, info, warning, error, critical)"
-    ),
+    base_dir: str | None = typer.Option(None, "--base-dir", "-d", help="Base directory for the pipeline"),
+    storage_options: str | None = typer.Option(None, "--storage-options", "-s", help="Storage options as JSON, dict string, or key=value pairs"),
+    log_level: str | None = typer.Option(None, "--log-level", help="Logging level (debug, info, warning, error, critical)"),
 ):
     """
     Add a hook to a pipeline configuration.
@@ -953,7 +592,9 @@ def add_hook(
         # Add a hook for all nodes with a specific tag
         $ pipeline add-hook my_pipeline --function log_metrics --type NODE_POST_EXECUTE --to @metrics
     """
-    parsed_storage_options = parse_dict_or_list_param(storage_options, "dict")
+    base_dir, parsed_storage_options, log_level = parse_common_options(
+        base_dir, storage_options, log_level
+    )
 
     # Validate 'to' argument for node hooks
     if type in (HookType.NODE_PRE_EXECUTE, HookType.NODE_POST_EXECUTE) and not to:
@@ -963,7 +604,7 @@ def add_hook(
 
     with PipelineManager(
         base_dir=base_dir,
-        storage_options=parsed_storage_options or {},
+        storage_options=parsed_storage_options,
         log_level=log_level,
     ) as manager:
         try:
@@ -976,5 +617,9 @@ def add_hook(
             logger.info(
                 f"Hook '{function_name}' added to pipeline '{name}' (type: {type.value})."
             )
+        except (FileNotFoundError, PermissionError, OSError) as e:
+            logger.error(f"File system error adding hook to pipeline '{name}': {e}")
+        except ValueError as e:
+            logger.error(f"Invalid configuration for hook addition: {e}")
         except Exception as e:
             logger.error(f"Failed to add hook to pipeline '{name}': {e}")
